#include <osgParticle/Version>

const char* osgParticleGetVersion()
{
    return "1.1";
}


const char* osgParticleGetLibraryName()
{
    return "OpenSceneGraph Particle Library";
}
